"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const botbuilder_calling_1 = require("botbuilder-calling");
function matchIntent(options, intent) {
    return options.match === intent.intent && (!options.threshold || intent.score > options.threshold);
}
class LuisDialog extends botbuilder_calling_1.Dialog {
    constructor(dialog) {
        super();
        this.dialog = dialog;
        LuisDialog.intents.push(this);
        this.id = (LuisDialog.intents.length).toString();
    }
    static findTrigger(session, intent) {
        const dialog = LuisDialog.intents
            .filter((x) => x.triggerOptions)
            .find((x) => matchIntent(x.triggerOptions, intent));
        if (!dialog) {
            return null;
        }
        return LuisDialog.registerDialog(session, dialog);
    }
    static findCancel(session, intent) {
        const dialog = LuisDialog.intents
            .filter((x) => x.cancelOptions)
            .find((x) => matchIntent(x.cancelOptions, intent));
        if (!dialog) {
            return null;
        }
        return LuisDialog.registerDialog(session, dialog);
    }
    static registerDialog(session, dialog) {
        let lib = session.library.library('LUIS');
        if (!lib) {
            lib = session.library.library(new botbuilder_calling_1.Library('LUIS'));
        }
        if (dialog && !lib.dialog(dialog.id)) {
            lib.dialog(`${dialog.id}.intent`, dialog.dialog);
            lib.dialog(dialog.id, dialog.dialog);
        }
        return dialog;
    }
    begin(session, args) {
        console.log('begin luis');
        session.beginDialog(`LUIS:${this.id}.intent`, args);
    }
    replyReceived(session) {
        console.log('luis reply');
        throw new Error("Method not implemented.");
    }
    dialogResumed(session, result) {
        console.log('luis resume');
        if (result.error) {
            session.error(result.error);
        }
    }
    triggerAction(action) {
        this.triggerOptions = action;
        return this;
    }
    cancelAction(action) {
        this.cancelOptions = action;
        return this;
    }
}
LuisDialog.intents = [];
exports.LuisDialog = LuisDialog;
