import { CallSession, Dialog, IAction, IDialogResult, IIsAction, IRecording, IRecordPromptOptions, Library } from 'botbuilder-calling';
import { LuisClient, LuisResult } from 'cognitive-luis-client';
import { SpeechClient, SpeechResult } from 'cognitive-speech-client';
export declare type PlayPrompt = string | string[] | IAction | IIsAction;
export declare enum PromptType {
    action = 0,
    confirm = 1,
    choice = 2,
    digits = 3,
    record = 4,
    speechToText = 5,
    understanding = 6,
    understandingChoice = 7,
}
export interface IPromptArgs {
    promptType: PromptType;
    action: IAction;
    maxRetries: number;
}
export interface ISpeechRecording extends IRecording {
    speech: SpeechResult;
}
export interface IUnderstandRecording extends ISpeechRecording {
    language: LuisResult;
    intercepted: boolean;
    choice: IChoice;
}
export interface ISpeechResult extends IDialogResult<ISpeechRecording> {
}
export interface IUnderstandResult extends IDialogResult<IUnderstandRecording> {
}
export interface IPromptsSettings {
    recognizeSilencePrompt?: PlayPrompt;
    invalidDtmfPrompt?: PlayPrompt;
    invalidRecognizePrompt?: PlayPrompt;
    recordSilencePrompt?: PlayPrompt;
    maxRecordingPrompt?: PlayPrompt;
    invalidRecordingPrompt?: PlayPrompt;
    noSpeech?: PlayPrompt;
}
export interface IChoice {
    name: string;
    variants?: string[];
}
export interface IRecordChoiceOptions extends IRecordPromptOptions {
    choices: IChoice[];
}
export declare class SpeechDialog extends Dialog {
    private speech;
    private luis;
    private prompts;
    static recognizeSpeech(session: CallSession, playPrompt: PlayPrompt, options?: IRecordPromptOptions): void;
    static understandSpeech(session: CallSession, playPrompt: PlayPrompt, options?: IRecordPromptOptions): void;
    static understandChoice(session: CallSession, playPrompt: PlayPrompt, options: IRecordChoiceOptions): void;
    constructor(speech: SpeechClient, luis: LuisClient, prompts?: IPromptsSettings);
    begin(session: CallSession, args: IPromptArgs): void;
    replyReceived(session: CallSession): void;
    dialogResumed(session: CallSession, result: IDialogResult<any>): void;
    private selectChoice(session, result, args);
    private luisError(err, result);
    private speechError(err, result);
    private receiveRecordOutcome(response, outcome, result);
    private routeResponse(session, result, args);
    private triggerCancel(session, result);
    private triggerIntent(session, result);
    private trigger(session, intentDialog, result, action);
    private canMatch(session);
}
export declare const SPEECH_LIBRARY_NAME = "Speech";
export declare const SPEECH_DIALOG_NAME: string;
export declare function speechLibrary(speech: SpeechClient, luis: LuisClient): Library;
